@@ -214,6 +214,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
 {
 #ifdef USE_MPI
     boost::mpi::communicator world;
+    world.barrier();
 #endif
     VectorXd initialValues = ArrayXd::Constant(1, 1.);
     VectorXd sigma  = ArrayXd::Constant(1, 0.2);
@@ -265,6 +266,9 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
         double valueSeqContinuation   = resolutionSwingContinuation(simulator, payoff, regressor, dates, N);
         BOOST_CHECK_EQUAL(valueSeq, valueSeqContinuation);
     }
+#ifdef USE_MPI
+    world.barrier();
+#endif
     // simulator
     shared_ptr<BlackScholesSimulator>  simulator(new BlackScholesSimulator(initialValues, sigma, mu, corr, dates(dates.size() - 1), dates.size() - 1, nbSimul, false)) ;
     // grid
@@ -288,15 +292,12 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
     shared_ptr<BaseRegression > regressor(new LocalLinearRegression(nbMesh));
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator);
-    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile
-#ifdef USE_MPI
-                        , world
-#endif
-                                                          );
+    double valueParal = DynamicProgrammingByRegressionDist(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDumpDistr, bOneFile, world                                                          );
     if (world.rank() == 0)
     {
         BOOST_CHECK_EQUAL(valueSeq, valueParal);
     }
+    world.barrier();
 #else
     string fileToDump = "CondExp";
     // simulator
@@ -306,15 +307,8 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimization)
     // link the simulations to the optimizer
     optimizer->setSimulator(simulator1);
     // using continuation values
-    double value =  DynamicProgrammingByRegression(grid, optimizer, regressor1, vFunction, initialStock, initialRegime, fileToDump
-#ifdef USE_MPI
-                    , world
-#endif
-                                                  );
-#ifdef USE_MPI
-    if (world.rank() == 0)
-#endif
-        BOOST_CHECK_EQUAL(valueSeq, value);
+    double value =  DynamicProgrammingByRegression(grid, optimizer, regressor1, vFunction, initialStock, initialRegime, fileToDump);
+    BOOST_CHECK_EQUAL(valueSeq, value);
 #endif
 }
 // only if 64 bits
@@ -323,6 +317,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
 {
 #ifdef USE_MPI
     boost::mpi::communicator world;
+    world.barrier();
 #endif
     VectorXd initialValues = ArrayXd::Constant(1, 1.);
     VectorXd sigma  = ArrayXd::Constant(1, 0.2);
@@ -350,7 +345,8 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
     double valueSeq ;
 
 #ifdef USE_MPI
-    if (world.rank() == 0)
+  world.barrier();
+  if (world.rank() == 0)
 #endif
     {
         // simulator
@@ -363,7 +359,8 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
         cout << " analytical " << analytical << " valueSeq " << valueSeq << std::endl ;
     }
 #ifdef USE_MPI
-    if (world.rank() == 0)
+  world.barrier();
+  if (world.rank() == 0)
 #endif
     {
         // simulator
@@ -391,6 +388,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
     int initialRegime = 0;
     string fileToDumpDistr = "CondExpDistr";
 #ifdef USE_MPI
+    world.barrier();
     fileToDumpDistr = fileToDumpDistr + to_string(world.size());
     bool bOneFile = false;
     // regressor
@@ -413,10 +411,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
     optimizer->setSimulator(simulator1);
     // using continuation values
     double value =  DynamicProgrammingByRegression(grid, optimizer, regressor, vFunction, initialStock, initialRegime, fileToDump);
-#ifdef USE_MPI
-    if (world.rank() == 0)
-#endif
-        BOOST_CHECK_EQUAL(valueSeq, value);
+    BOOST_CHECK_EQUAL(valueSeq, value);
 #endif
 }
 // only if 64 bits 
@@ -427,6 +422,7 @@ BOOST_AUTO_TEST_CASE(testSwingOptionInOptimizationKernel)
 void testMultiStock(const int p_ndim)
 {
     boost::mpi::communicator world;
+    world.barrier();
     VectorXd initialValues = ArrayXd::Constant(1, 1.);
     VectorXd sigma  = ArrayXd::Constant(1, 0.2);
     VectorXd mu  = ArrayXd::Constant(1, 0.05);
@@ -456,6 +452,7 @@ void testMultiStock(const int p_ndim)
         // Bermudean value
         valueSeq = resolutionSwing(simulator, payoff, regressor, dates, N);
     }
+    world.barrier();
     // simulator
     shared_ptr<BlackScholesSimulator>  simulator(new BlackScholesSimulator(initialValues, sigma, mu, corr, dates(dates.size() - 1), dates.size() - 1, nbSimul, false));
     // grid
@@ -482,6 +479,7 @@ void testMultiStock(const int p_ndim)
     {
         BOOST_CHECK_CLOSE(valueSeq * p_ndim, valueParal, accuracyNearlyEqual);
     }
+    world.barrier();
 }
 
 BOOST_AUTO_TEST_CASE(testSwingOption2D)
